MP4
===

.. automodule:: mutagen.mp4

MP4
---

.. autoclass:: mutagen.mp4.MP4(filename)
    :show-inheritance:
    :members:
    :exclude-members: MP4Tags

.. autoclass:: mutagen.mp4.MP4Tags()
    :show-inheritance:
    :members:

.. autoclass:: mutagen.mp4.MP4Info()
    :members:

.. autoclass:: mutagen.mp4.MP4Cover
    :members:

.. autoclass:: mutagen.mp4.MP4FreeForm
    :members:

.. function:: mutagen.mp4.Open(filename)

.. autofunction:: mutagen.mp4.delete


EasyMP4
-------

.. automodule:: mutagen.easymp4

.. autoclass:: mutagen.easymp4.EasyMP4(filename)
    :show-inheritance:
    :members:
    :exclude-members: MP4Tags


.. autoclass:: mutagen.easymp4.EasyMP4Tags()
    :show-inheritance:
    :members:
